| Title: | Genomic Prediction of Hybrid Performance with Graphical User Interface |
|---|---|
| Description: | Performs genomic prediction of hybrid performance using eight GS methods including GBLUP, BayesB, RKHS, PLS, LASSO, Elastic net, XGBoost and LightGBM. GBLUP: genomic best liner unbiased prediction, RKHS: reproducing kernel Hilbert space, PLS: partial least squares regression, LASSO: least absolute shrinkage and selection operator, XGBoost: extreme gradient boosting, LightGBM: light gradient boosting machine. It also provides fast cross-validation and mating design scheme for training population (Xu S et al (2016) <doi:10.1111/tpj.13242>; Xu S (2017) <doi:10.1534/g3.116.038059>). A complete manual for this package is provided in the manual folder of the package installation directory. You can locate the manual by running the following command in R: system.file("manual", package = "predhy.GUI"). |
| Authors: | Yang Xu [aut], Guangning Yu [aut], Yuxiang Zhang [aut, cre], Yanru Cui [ctb], Shizhong Xu [ctb], Chenwu Xu [ctb] |
| Maintainer: | Yuxiang Zhang <[email protected]> |
| License: | GPL-3 |
| Version: | 2.1.1 |
| Built: | 2026-06-01 10:18:51 UTC |
| Source: | https://github.com/cran/predhy.GUI |
This dataset contains phenotypic data of 410 hybrids for grain yield in maize.
hybrid_phehybrid_phe
A data frame with 410 rows and 3 variables:
MThe names of male parents.
FThe names of female parents.
GYThe grain yield of hybrids.
Genotypic data of 348 maize inbred lines in Hapmap format with double bit.
input_genoinput_geno
A data frame with 4979 rows and 359 columns.
Genotypic data of 50 rice inbred lines with 1000 SNPs.
input_geno1input_geno1
A data frame with 1000 rows and 50 variables.
Graphical User Interface for cross validation, genotype conversion and hybrid performance prediction.
predhy.GUI()predhy.GUI()
No return value, called for Graphical User Interface
{ predhy.GUI()}{ predhy.GUI()}